==> ginkgocadx_3.7.5.orig.tar.gz: ginkgocadx-3.7.5/cadxcore/main/tools/trackballtool.h <==
#pragma once
/*
 * This file is part of Ginkgo CADx
 *
 * Copyright (c) 2015-2016 Gert Wollny
 * Copyright (c) 2008-2014 MetaEmotion S.L. All rights reserved.
 *
 * Ginkgo CADx is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation; version 3. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser Public License
 * along with Ginkgo CADx; if not, see <http://www.gnu.org/licenses/>.
 *
 */

#pragma once

#ifndef TRACKBALLTOOL_H
#define TRACKBALLTOOL_H

#include <export/tools/itrackballtool.h>
#include <api/api.h>

namespace GNC {
	namespace GCS {
		namespace Widgets {
			class WTrackballBuilder;
		}
		namespace Events {
			class EventoRaton;
			class EventoTeclado;
		}
	}

	class EXTAPI TrackballTool : public GNC::GCS::ITrackballTool {
	public:
		typedef GNC::GCS::Events::EventoRaton       TEventoRaton;
		typedef GNC::GCS::Events::EventoTeclado     TEventoTeclado;
		typedef GNC::GCS::Widgets::WTrackballBuilder TBuilder;
		TrackballTool();
		~TrackballTool();

//region "Realización de la interfaz IHerramienta"

		virtual GNC::GCS::ITool* NewTool();
		virtual void Connect();
		virtual void Disconnect();

//endregion


//region "Eventos refinados desde los paneles"

//endregion

	protected:

		TBuilder*            m_pBuilder;
	};
}
#endif

==> ginkgocadx_3.8.8.orig.tar.gz: ginkgocadx-3.8.8/cadxcore/main/tools/trackballtool.h <==
#pragma once
/*
 * This file is part of Ginkgo CADx
 *
 * Copyright (c) 2015-2016 Gert Wollny
 * Copyright (c) 2008-2014 MetaEmotion S.L. All rights reserved.
 *
 * Ginkgo CADx is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser Public License
 * along with Ginkgo CADx; if not, see <http://www.gnu.org/licenses/>.
 *
 */

#pragma once

#ifndef TRACKBALLTOOL_H
#define TRACKBALLTOOL_H

#include <export/tools/itrackballtool.h>
#include <api/api.h>

namespace GNC
{
namespace GCS
{
namespace Widgets
{
class WTrackballBuilder;
}
namespace Events
{
class EventoRaton;
class EventoTeclado;
}
}

class EXTAPI TrackballTool : public GNC::GCS::ITrackballTool
{
public:
        typedef GNC::GCS::Events::EventoRaton       TEventoRaton;
        typedef GNC::GCS::Events::EventoTeclado     TEventoTeclado;
        typedef GNC::GCS::Widgets::WTrackballBuilder TBuilder;
        TrackballTool();
        ~TrackballTool();

//region "Realización de la interfaz IHerramienta"

        virtual GNC::GCS::ITool* NewTool();
        virtual void Connect();
        virtual void Disconnect();

//endregion


//region "Eventos refinados desde los paneles"

//endregion

protected:

        TBuilder*            m_pBuilder;
};
}
#endif
